pub struct ConfigCookbookProvider<'a, R: LoadableLibResolver + ?Sized> { /* private fields */ }Expand description
Cookbook config provider backed by a merged effective config Dir.
Implementations
Sourceimpl<'a, R: LoadableLibResolver + ?Sized> ConfigCookbookProvider<'a, R>
impl<'a, R: LoadableLibResolver + ?Sized> ConfigCookbookProvider<'a, R>
Sourcepub fn new(effective: &EffectiveConfig, resolver: &'a R) -> Self
pub fn new(effective: &EffectiveConfig, resolver: &'a R) -> Self
Reads the effective sim/cookbook table and prepares a directory
provider over resolver.
Sourcepub fn new_with_base(
effective: &EffectiveConfig,
base: CookbookConfig,
resolver: &'a R,
) -> Self
pub fn new_with_base( effective: &EffectiveConfig, base: CookbookConfig, resolver: &'a R, ) -> Self
Reads the effective sim/cookbook table as an overlay over base.
Sourcepub fn config(&self) -> &CookbookConfig
pub fn config(&self) -> &CookbookConfig
Returns the effective cookbook config snapshot.
Sourcepub fn minimum_loaded(&self) -> &[String]
pub fn minimum_loaded(&self) -> &[String]
Returns the configured minimum boot set without loading it.
Sourcepub fn loadable_libs(&self) -> (LoadableLibList, Vec<String>)
pub fn loadable_libs(&self) -> (LoadableLibList, Vec<String>)
Resolves the configured loadable-lib directory.