pub struct CookbookStoreHandle { /* private fields */ }Expand description
A runtime value that exposes the shared recipe store to projection layers.
Implementations
Sourceimpl CookbookStoreHandle
impl CookbookStoreHandle
Sourcepub fn new(store: Arc<Mutex<RecipeStore>>) -> Self
pub fn new(store: Arc<Mutex<RecipeStore>>) -> Self
Build a handle over the store used by the cookbook: ops.
Sourcepub fn store(&self) -> Arc<Mutex<RecipeStore>>
pub fn store(&self) -> Arc<Mutex<RecipeStore>>
Return the shared store handle.