LoadableLibEntry

Struct LoadableLibEntry 

pub struct LoadableLibEntry {
    pub id: String,
    pub source: String,
    pub title: String,
    pub order: i64,
    pub recipes: Option<EmbeddedDir>,
    pub catalog_lib: Box<dyn Lib + Send + Sync>,
    pub factory: LibFactory,
}
One known library in the cookbook’s effective loadable-lib directory.

Fields

id: String

Cookbook-facing library id, such as numbers/cas.

source: String

Host resolver source key, such as symbol:numbers/cas.

title: String

Human title used for this library’s cookbook book.

order: i64

Book display order.

recipes: Option<EmbeddedDir>

Embedded recipes for this lib, when the host can expose them.

catalog_lib: Box<dyn Lib + Send + Sync>

Catalog instance used to resolve ordinary recipe requires.

factory: LibFactory

Factory used by lifecycle execution to create a fresh lib instance.