pub struct LoadableLibEntry {
pub id: String,
pub source: String,
pub title: String,
pub order: i64,
pub recipes: Option<EmbeddedDir>,
pub catalog_lib: Box<dyn Lib + Send + Sync>,
pub factory: LibFactory,
}Expand description
One known library in the cookbook’s effective loadable-lib directory.
Fields
id: StringCookbook-facing library id, such as numbers/cas.
source: StringHost resolver source key, such as symbol:numbers/cas.
title: StringHuman title used for this library’s cookbook book.
order: i64Book display order.
recipes: Option<EmbeddedDir>Embedded recipes for this lib, when the host can expose them.
catalog_lib: Box<dyn Lib + Send + Sync>Catalog instance used to resolve ordinary recipe requires.
factory: LibFactoryFactory used by lifecycle execution to create a fresh lib instance.